@@ -46,6 +46,13 @@ helps['sql db show'] = """
     type: command
     short-summary: Get the details for a database.
     """
+helps['sql db show-connection-string'] = """
+    type: command
+    short-summary: Generates a connection string to a database.
+    examples:
+        - name: Generate connection string for ado.net
+          text: az sql db show-connection-string -s myserver -n mydb -c ado.net
+    """
 helps['sql db update'] = """
     type: command
     short-summary: Update a database.
@@ -277,6 +284,18 @@ helps['sql server update'] = """
     type: command
     short-summary: Update a server.
     """
+helps['sql server conn-policy'] = """
+    type: group
+    short-summary: Manage a server's connection policy.
+    """
+helps['sql server conn-policy show'] = """
+    type: command
+    short-summary: Gets a server's secure connection policy.
+    """
+helps['sql server conn-policy update'] = """
+    type: command
+    short-summary: Updates a server's secure connection policy.
+    """
 helps['sql server firewall-rule'] = """
     type: group
     short-summary: Manage a server's firewall rules.
