@@ -9,7 +9,9 @@ from azure.cli.core.commands import CliArgumentType, register_extra_cli_argument
 from azure.cli.core.commands.parameters import (
     enum_choice_list,
     ignore_type,
-    get_resource_name_completion_list)
+    get_resource_name_completion_list,
+    location_type,
+    three_state_flag)
 from azure.cli.core.sdk.util import ParametersContext, patch_arg_make_required, patch_arg_make_optional
 from azure.mgmt.sql.models.database import Database
 from azure.mgmt.sql.models.elastic_pool import ElasticPool
@@ -24,6 +26,7 @@ from azure.mgmt.sql.models.sql_management_client_enums import (
     CreateMode,
     SecurityAlertPolicyState,
     SecurityAlertPolicyEmailAccountAdmins,
+    ServerConnectionType,
     ServerKeyType,
     StorageKeyType,
     TransparentDataEncryptionStatus)
@@ -44,6 +47,7 @@ server_param_type = CliArgumentType(
     options_list=('--server', '-s'),
     help='Name of the Azure SQL server.')
 
+
 #####
 #        SizeWithUnitConverter - consider moving to common code (azure.cli.core.commands.parameters)
 #####
@@ -78,6 +82,11 @@ class SizeWithUnitConverter(object):  # pylint: disable=too-few-public-methods
             ', '.join(sorted(self.unit_map, key=self.unit_map.__getitem__)))
 
 
+with ParametersContext(command='sql') as c:
+    c.argument('location_name', arg_type=location_type)
+    c.argument('usage_name', options_list=('--usage', '-u'))
+
+
 ###############################################
 #                sql db                       #
 ###############################################
@@ -113,6 +122,9 @@ def _configure_db_create_params(
     create_mode: Valid CreateMode enum value (e.g. `default`, `copy`, etc)
     """
 
+    # This line to be removed when zone redundancy is fully supported in production.
+    cmd.ignore('zone_redundant')
+
     # DW does not support all create modes. Check that engine and create_mode are consistent.
     if engine == Engine.dw and create_mode not in [
             CreateMode.default,
@@ -140,6 +152,7 @@ def _configure_db_create_params(
     # Only applicable to default create mode. Also only applicable to db.
     if create_mode != CreateMode.default or engine != Engine.db:
         cmd.ignore('sample_name')
+        cmd.ignore('zone_redundant')
 
     # Only applicable to point in time restore or deleted restore create mode.
     if create_mode not in [CreateMode.restore, CreateMode.point_in_time_restore]:
@@ -552,6 +565,9 @@ with ParametersContext(command='sql dw show') as c:
 
 
 with ParametersContext(command='sql elastic-pool') as c:
+    # This line to be removed when zone redundancy is fully supported in production.
+    c.ignore('zone_redundant')
+
     c.argument('elastic_pool_name',
                options_list=('--name', '-n'),
                help='The name of the elastic pool.')
@@ -671,6 +687,16 @@ with ParametersContext(command='sql server ad-admin create') as c:
         'tenant_id': patch_arg_make_optional})
 
 
+#####
+#           sql server conn-policy
+#####
+
+
+with ParametersContext(command='sql server conn-policy') as c:
+    c.argument('server_name', arg_type=server_param_type)
+    c.argument('connection_type', options_list=('--connection-type', '-t'), **enum_choice_list(ServerConnectionType))
+
+
 #####
 #           sql server firewall-rule
 #####
@@ -750,5 +776,10 @@ with ParametersContext(command='sql server vnet-rule') as c:
                help='Name or ID of the subnet that allows access to an Azure Sql Server. '
                'If subnet name is provided, --vnet-name must be provided.')
 
+    c.argument('ignore_missing_vnet_service_endpoint',
+               options_list=('--ignore-missing-endpoint', '-i'),
+               help='Create firewall rule before the virtual network has vnet service endpoint enabled',
+               **three_state_flag())
+
 register_extra_cli_argument('sql server vnet-rule create', 'vnet_name', options_list=('--vnet-name'),
                             help='The virtual network name', validator=validate_subnet)
